@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::BaseClientRole';
 
-our $VERSION = '0.0200'; # VERSION
+our $VERSION = '0.0201'; # VERSION
 
 use Carp qw(croak);
 
@@ -139,7 +139,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -157,7 +157,8 @@ version 0.0200
 =head1 DESCRIPTION
 
 This module provides bindings for the
-L<HipChat|https://www.hipchat.com/docs/apiv2> API v2.
+L<HipChat API v2|https://www.hipchat.com/docs/apiv2>.
+It also provides the command line utility L<hipchat-send>.
 
 =head1 METHODS
 
